@@ -1,6 +1,6 @@
 # coding: utf-8
 #
-# Copyright (c) 2011, CN-Software Ltd.
+# Copyright (c) 2012, CN-Software Ltd.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without modification,
@@ -43,10 +43,10 @@ Documentation: http://geobaza.ru/docs/python/v1/.
 Detailed information and updates: http://geobaza.ru/.
 """
 
-__copyright__ = "Copyright 2011, CN-Software Ltd."
+__copyright__ = "Copyright 2012, CN-Software Ltd."
 
 __license__ = "New-style BSD"
-__version__ = "1.0.2.11.12"
+__version__ = "1.0.4.12.09"
 __email__ = "support@cn-software.com"
 __status__ = "Production"
 
@@ -56,7 +56,7 @@ import struct
 import decimal
 import xml.etree.cElementTree as etree
 from time import time
-from datetime import datetime
+from datetime import datetime as dt
 import simplejson as json
 
 from geobaza.utils import validate_ip, Bunch, to_str, prettify_xml, singleton_init
@@ -765,7 +765,7 @@ class GeobazaQuery(object):
 
         # Headers
         headers = json.loads(self.f.read(self.f.unpack(2, '!H')))
-        headers['build_date'] = datetime.strptime(headers['build_date'], '%a %b %d %H:%M:%S %Z %Y')
+        headers['build_date'] = dt.fromtimestamp(headers['build_timestamp'])
         headers['lite'] = headers.has_key('lite')
         headers['release'] = headers['release'].strip()
         self.headers = Headers(**headers)
